WorkflowSpecV0

Struct WorkflowSpecV0 

pub struct WorkflowSpecV0(pub Map<String, Value>);
A workflow.v0 spec. The canonical JSON Schema is available at /schemas/workflow_v0.schema.json.

JSON schema
{
 "description": "A `workflow.v0` spec. The canonical JSON Schema is available at `/schemas/workflow_v0.schema.json`.",
 "type": "object",
 "additionalProperties": true
}

Tuple Fields

0: Map<String, Value>

Methods from Deref<Target = Map<String, Value>>

pub fn get<Q>(&self, key: &Q) -> Option<&Value>
where String: Borrow<Q>, Q: Ord + Eq + Hash + ?Sized,

Returns a reference to the value corresponding to the key.

The key may be any borrowed form of the map’s key type, but the ordering on the borrowed form must match the ordering on the key type.

pub fn contains_key<Q>(&self, key: &Q) -> bool
where String: Borrow<Q>, Q: Ord + Eq + Hash + ?Sized,

Returns true if the map contains a value for the specified key.

The key may be any borrowed form of the map’s key type, but the ordering on the borrowed form must match the ordering on the key type.

pub fn get_key_value<Q>(&self, key: &Q) -> Option<(&String, &Value)>
where String: Borrow<Q>, Q: Ord + Eq + Hash + ?Sized,

Returns the key-value pair matching the given key.

The key may be any borrowed form of the map’s key type, but the ordering on the borrowed form must match the ordering on the key type.

pub fn len(&self) -> usize

Returns the number of elements in the map.

pub fn is_empty(&self) -> bool

Returns true if the map contains no elements.

pub fn iter(&self) -> Iter<'_>

Gets an iterator over the entries of the map.

pub fn keys(&self) -> Keys<'_>

Gets an iterator over the keys of the map.

pub fn values(&self) -> Values<'_>

Gets an iterator over the values of the map.