pub struct AuthClient { /* private fields */ }Expand description
Async client for customer token operations.
Implementations
Sourceimpl AuthClient
impl AuthClient
Sourcepub async fn customer_token(
&self,
req: CustomerTokenRequest,
) -> Result<CustomerToken, Error>
pub async fn customer_token( &self, req: CustomerTokenRequest, ) -> Result<CustomerToken, Error>
Mint a customer-scoped bearer token (requires secret key auth).
Sourcepub async fn get_or_create_customer_token(
&self,
req: GetOrCreateCustomerTokenRequest,
) -> Result<CustomerToken, Error>
pub async fn get_or_create_customer_token( &self, req: GetOrCreateCustomerTokenRequest, ) -> Result<CustomerToken, Error>
Get or create a customer and mint a bearer token.
This is a convenience method that:
- Upserts the customer (creates if not exists)
- Mints a customer-scoped bearer token
Use this when you want to ensure the customer exists before minting a token,
without needing to handle 404 errors from customer_token().
Requires a secret key.