Module generated

Module generated 

Generated types from OpenAPI spec. Run just generate-sdk-types to regenerate from api/openapi/api.yaml. Auto-generated types from OpenAPI spec.

Types are generated at compile time from api/openapi/api.json via build.rs. No generated files are checked into git - types are always fresh.

Usage

use modelrelay::generated::{Customer, Tier, Project, MessageRole, Citation};
use modelrelay::generated::MessageRoleExt; // Extension trait for as_str()

Modules

error
Error types.

Structs

ApiError
ApiError
AuthResponse
AuthResponse
AuthTokens
AuthTokens
Citation
Citation
ContentPart
ContentPart
Customer
Customer
CustomerCreate
CustomerCreate
CustomerCreateExternalId
External customer identifier from your system
CustomerExternalId
External customer identifier from your system
CustomerMe
CustomerMe
CustomerMeExternalId
External customer identifier from your system
CustomerMeResponse
CustomerMeResponse
CustomerMeUsage
Usage summary for the current billing period.
CustomerMeUsageResponse
CustomerMeUsageResponse
CustomerTokenResponse
CustomerTokenResponse
CustomerTokenResponseCustomerExternalId
External customer identifier
DeviceStartResponse
DeviceStartResponse
DeviceTokenError
DeviceTokenError
InputItem
InputItem
JsonSchemaFormat
JsonSchemaFormat
Model
Model
ModelId
LLM model identifier (e.g., claude-sonnet-4-20250514, gpt-4o).
ModelsResponse
ModelsResponse
NdjsonStreamEvent
Events sent during streaming responses (application/x-ndjson). Each line is a JSON object with an “event” field indicating the type.
NodeErrorV0
NodeErrorV0
NodeId
Workflow node identifier. Must start with a lowercase letter and contain only lowercase letters, numbers, and underscores.
NodeResultV0
NodeResultV0
OutputFormat
OutputFormat
OutputItem
OutputItem
PlanHash
SHA-256 hash of the compiled workflow plan (64 hex characters).
PluginAgentV0
PluginAgentV0
PluginCommandV0
PluginCommandV0
PluginGitHubRefV0
PluginGitHubRefV0
PluginManifestV0
PluginManifestV0
PluginsLoadRequest
PluginsLoadRequest
PluginsLoadResponseV0
PluginsLoadResponseV0
PluginsRunRequest
PluginsRunRequest
PluginsRunResponseV0
PluginsRunResponseV0
Project
Project
RequestId
Unique identifier for an LLM request within a workflow run.
ResponsesBatchError
ResponsesBatchError
ResponsesBatchRequest
ResponsesBatchRequest
ResponsesBatchRequestOptions
ResponsesBatchRequestOptions
ResponsesBatchResponse
ResponsesBatchResponse
ResponsesBatchResult
ResponsesBatchResult
ResponsesRequest
ResponsesRequest
ResponsesResponse
ResponsesResponse
ResponsesStreamEnvelope
ResponsesStreamEnvelope
RunCostLineItemV0
RunCostLineItemV0
RunCostSummaryV0
RunCostSummaryV0
RunId
Unique identifier for a workflow run.
RunsCreateOptionsV0
RunsCreateOptionsV0
RunsCreateRequest
RunsCreateRequest
RunsCreateResponse
RunsCreateResponse
RunsGetResponse
RunsGetResponse
RunsPendingToolCallV0
A pending tool call waiting for a result.
RunsPendingToolsNodeV0
A node with pending tool calls.
RunsPendingToolsResponse
Response containing pending tool calls for a workflow run.
Sha256Hash
SHA-256 hash (64 hex characters).
SubscriptionStatus
Subscription status for a customer.
Tier
Tier
TierCode
Tier code identifier (e.g., free, pro, enterprise).
TierCreate
TierCreate
TierCreateDisplayName
Human-readable tier name
TierDisplayName
Human-readable tier name
TierModel
TierModel
TierModelCreate
TierModelCreate
TierUpdate
TierUpdate
TierUpdateDisplayName
Human-readable tier name
Tool
Tool
ToolCall
ToolCall
ToolCallDelta
Incremental tool call data during streaming
ToolCallDeltaFunction
ToolCallDeltaFunction
ToolCallFunction
ToolCallFunction
ToolChoice
ToolChoice
ToolFunction
ToolFunction
Usage
Token usage statistics. All fields default to 0 if not present.
User
User
WorkflowSpecV0
A workflow.v0 spec. The canonical JSON Schema is available at /schemas/workflow_v0.schema.json.

Enums

ContentPartType
ContentPartType
CustomerMeUsageState
Whether the customer can make more requests
InputItemType
InputItemType
MessageRole
MessageRole
ModelCapability
Workflow-critical model capability identifier.
ModelRelayApi
Generated types from ModelRelay OpenAPI spec
NdjsonStreamEventEvent
Event type
NodeStatusV0
NodeStatusV0
NodeTypeV0
Type of workflow node.
OutputFormatType
OutputFormatType
OutputItemType
OutputItemType
PriceInterval
Billing interval for a tier.
ProjectCustomerOauthProvidersItem
ProjectCustomerOauthProvidersItem
ProviderId
LLM provider identifier.
ResponsesStreamEnvelopeType
ResponsesStreamEnvelopeType
RunStatusV0
RunStatusV0
ToolCallType
ToolCallType
ToolChoiceType
ToolChoiceType
ToolType
ToolType

Traits

MessageRoleExt
Extension trait for MessageRole providing convenience methods.